@@ -138,10 +138,11 @@ def record_names_timestamp():
     from time import ctime
     from IPython.display import display, HTML
     from IPython.display import Javascript as JS
-    userstr = 'User: ' + environ['USER'] + ' | Computer: ' + \
-              uname()[1] + ' | Time: ' + ctime()
+    userstr = 'Initialization -- Computer: ' + uname()[1] +' | User: ' + \
+              environ['USER'] +  ' | Time: ' + ctime()
     display(HTML(
-        '<span id="Last-User" style="font-weight:bold;">' + userstr + '</span>'))
+        '<div id="Last-User" style="font-weight:bold;">' + userstr +
+        '</div>'))
     select_containing_cell("Last-User")
     OTJS('JPSLUtils.record_names()')
     pass
